@@ -5,9 +5,10 @@ import numpy as np
 import pytest
 
 from .. import Backend
+from . import AVAILABLE_BACKENDS
 
 
-@pytest.mark.parametrize('key', Backend.backends.keys())
+@pytest.mark.parametrize('key', AVAILABLE_BACKENDS)
 def test_banded_jacobian(key):
     be = Backend(key)
     n = 3
